@@ -142,6 +142,9 @@ SERVICE_VERSIONS = {
     "cds": [
         "2018-04-20"
     ],
+    "cdwch": [
+        "2020-09-15"
+    ],
     "cfg": [
         "2021-08-20"
     ],
@@ -632,6 +635,9 @@ SERVICE_VERSIONS = {
     "tmt": [
         "2018-03-21"
     ],
+    "trdp": [
+        "2022-07-26"
+    ],
     "trp": [
         "2021-05-15"
     ],
